import QtQuick 1.0
import com.nokia.meego 1.0

Item {
    id: container

    property bool mobileAccessEnabled: true

    property bool isLocked: true

    property bool isCharging: false
    property bool normalChargingMode: true

    function setRoofState(newValue) {
        roofSlider.value = newValue;
    }

    Label {
        anchors.centerIn: parent
        visible: !container.mobileAccessEnabled
        text: "Mobile access disabled"
    }// "Mobile access disabled"

    Column {
        anchors.fill: parent

        spacing: 5

        Slider {
            id: roofSlider
            width: parent.width * 0.75
            anchors.horizontalCenter: parent.horizontalCenter
            visible: container.mobileAccessEnabled

            minimumValue: 0
            maximumValue: 3
            stepSize: 1

            onPressedChanged: {
                if (!pressed) {
                    g_MainWindow.setRoofStateInt(roofSlider.value);
                }
            }
        }//Slider (roof)

        Label {
            id: roofText
            anchors.horizontalCenter: parent.horizontalCenter
            visible: container.mobileAccessEnabled

            text: {
                if (roofSlider.value === 0) return "Roof closed";
                if (roofSlider.value === 1) return "Roof venting";
                if (roofSlider.value === 2) return "Roof in comfort position";
                if (roofSlider.value === 3) return "Roof fully open";
                return "Roof is open";
            }

            color: "white"
        }//Label (roof text)

        ButtonRow {
            visible: container.mobileAccessEnabled

            width: parent.width
            spacing: 2

            exclusive: true
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Lock"
                checkable: true
                checked: container.isLocked
                platformStyle: ButtonStyle { inverted: true }

                onClicked: { g_MainWindow.setLockState(true); }
            }
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Unlock"
                checkable: true
                checked: !container.isLocked
                platformStyle: ButtonStyle { inverted: true }

                onClicked: { g_MainWindow.setLockState(false); }
            }
        }//Lock / unlock

        ButtonRow {
            visible: container.mobileAccessEnabled

            width: parent.width
            spacing: 2

            exclusive: false
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Honk horn"
                platformStyle: ButtonStyle { inverted: true }

                onClicked: { g_MainWindow.honk(); }
            }
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Flash lights"
                platformStyle: ButtonStyle { inverted: true }

                onClicked: { g_MainWindow.flashLights(); }
            }
        }//Honk + Flash

        Label {
            anchors.horizontalCenter: parent.horizontalCenter
            visible: container.mobileAccessEnabled
            text: "Set charging mode:"
            platformStyle: LabelStyle { inverted: true }
        }// Label (set charging mode)

        ButtonRow {
            width: parent.width
            spacing: 2

            visible: container.mobileAccessEnabled

            exclusive: true
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Normal"
                platformStyle: ButtonStyle { inverted: true }
                checkable: true
                checked: container.normalChargingMode

                onClicked: { g_MainWindow.setChargingMode(true); }
            }
            Button {
                width: (parent.width / 2) - parent.spacing

                text: "Extended"
                platformStyle: ButtonStyle { inverted: true }
                checkable: true
                checked: !container.normalChargingMode

                onClicked: { g_MainWindow.setChargingMode(false); }
            }
        }//Charging mode (range charging OR extended charging)
    }//Column
}
