import QtQuick 1.0
import com.nokia.meego 1.0

Column {
    id: container

    property bool mobileAccessEnabled: true

    property string vin: "VIN"
    property string summaryState: "Car state is unknown"
    property string location: "Car location is unknown"

    property real idealRange: 300
    property real ratedRange: 1
    property real drivingRange: 1
    property string distanceStr

    property real batteryLevel: 1
    property bool isCharging: false
    property string remainingTimeToFullCharge: "1 hour"

    property string insideTemp
    property string outsideTemp

    property int bigPixels: 28
    spacing: 5

    Row {
        width: parent.width

        Label {
            id: lblVin
            text: "VIN"
            color: "white"
            font.pixelSize: bigPixels
            horizontalAlignment: Qt.AlignLeft
        }
        Label {
            text: container.vin
            color: "white"
            font.pixelSize: bigPixels
            horizontalAlignment: Qt.AlignRight
            width: parent.width - lblVin.width
        }
    }//vin

    Label {
        id: lblSummary
        anchors.horizontalCenter: parent.horizontalCenter

        text: container.summaryState
        platformStyle: LabelStyle { inverted: true }
        font.pixelSize: bigPixels

        horizontalAlignment: Text.AlignHCenter
    }//summary

    MyProgressBar {
        id: ratedRangeProgressBar

        anchors.horizontalCenter: parent.horizontalCenter
        width: parent.width * 0.75
        height: 50

        value: container.ratedRange
        minimumValue: 0
        maximumValue: container.idealRange
    }//rated range

    Label {
        id: lblRange
        anchors.horizontalCenter: parent.horizontalCenter

        property bool showRated: true

        text: container.distanceStr

        platformStyle: LabelStyle { inverted: true }
        font.pixelSize: ratedRangeProgressBar.height

        MouseArea {
            anchors.fill: parent
            onClicked: {
                parent.showRated = !parent.showRated;
            }
        }
    }//rated range text

    Label {
        id: lblChargingTime
        anchors.horizontalCenter: parent.horizontalCenter
        visible: container.isCharging

        text: "Time to full charge: " + container.remainingTimeToFullCharge
        platformStyle: LabelStyle { inverted: true }
    }//remaining charging time

    Row {
        width: parent.width
        height: lblLocation.height > edLocation.height ? lblLocation.height : edLocation.height
        spacing: 10

        Label {
            id: lblLocation
            text: "Location:"
            anchors.verticalCenter: parent.verticalCenter
        }

        Label {
            id: edLocation
            anchors.verticalCenter: parent.verticalCenter
            width: parent.width - lblLocation.width - parent.spacing

            text: container.location
            platformStyle: LabelStyle { inverted: true }
            //readOnly: true
        }//location text
    }

    Item {
        width: parent.width
        height: lblInsideTemp.height

        Label {
            id: lblInsideTemp

            anchors {
                left: parent.left
                leftMargin: 5
            }

            platformStyle: LabelStyle { inverted: true }
            text: "Inside temperature"
        }

        Label {
            anchors {
                right: parent.right
                rightMargin: 10
            }

            platformStyle: LabelStyle { inverted: true }
            text: container.insideTemp
        }
    }//Item insideTemp

    Item {
        width: parent.width
        height: lblOutsideTemp.height

        Label {
            id: lblOutsideTemp

            anchors {
                left: parent.left
                leftMargin: 5
            }

            platformStyle: LabelStyle { inverted: true }
            text: "Outside temperature"
        }

        Label {
            anchors {
                right: parent.right
                rightMargin: 10
            }

            platformStyle: LabelStyle { inverted: true }
            text: container.outsideTemp
        }
    }//Item outsideTemp
}//Item
