import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: container
    tools: btnRow

    property real toobarHeight: btnRow.height

    property real cSpacing: 2
    property real cWidth: container.width
    property real cHeight: container.height - container.cSpacing

    signal showAbout
    signal showMapOptions

    Row {
        id: viewRow

        anchors {
            top: parent.top
            bottom: btnRow.top
            bottomMargin: container.cSpacing
        }

        width: parent.width
        spacing: 2

        HomePage {
            height: container.cHeight
            width:  container.cWidth
            objectName: "HomePage"
        }

        ControlsPage {
            height: container.cHeight
            width:  container.cWidth
            objectName: "ControlsPage"
        }

        MapPage {
            id: mapPage
            height: container.cHeight
            width:  container.cWidth
            objectName: "MapPage"
        }

        Behavior on x { PropertyAnimation { duration: 500 } }
    }// Row of all views

    ToolBarLayout {
        id: btnRow

        anchors.bottom: parent.bottom
        width: parent.width

        ButtonRow {

            Button {
                text: "Home"
                onClicked: { container.state = "Home"; }
            }
            Button {
                text: "Controls"
                onClicked: { container.state = "Controls"; }
            }
            Button {
                text: "Map"
                onClicked: { container.state = "Map"; }
            }//ToolButton
        }//ToolButtonRow

        ToolButton {
            width: 70
            height: 50
            iconSource: "image://theme/icon-m-toolbar-view-menu"
            onClicked: { homeMenu.open(); }
        }//ToolButton
    }

    Menu {
        id: homeMenu
        //visualParent: parent

        content: MenuLayout {
            MenuItem {
                text: "Map options"
                visible: (container.state == "Map")
                onClicked: { container.showMapOptions(); }
            }
            MenuItem {
                text: "Switch cars"
                visible: (g_MainWindow.g_vehicleCount > 1)
                onClicked: { g_MainWindow.onUiSwitchCars(); }
            }
            MenuItem {
                text: "About"
                onClicked: { container.showAbout(); }
            }
            MenuItem {
                text: "Quit"
                onClicked: { Qt.quit(); }
            }
        }
    }

    states: [
        State {
            name: "Home"
            PropertyChanges {
                target: viewRow
                x: 0
            }
        },
        State {
            name: "Controls"
            PropertyChanges {
                target: viewRow
                x: (container.cWidth + viewRow.spacing) * -1
            }
        },
        State {
            name: "Map"
            PropertyChanges {
                target: viewRow
                x: (container.cWidth + viewRow.spacing) * -2
            }
        }
    ]// states

    Component.onCompleted: {
        container.state = "Home"
    }

}//Page
